summaryrefslogtreecommitdiff
path: root/test/smp/regression/threadx_thread_delayed_suspension_test.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/smp/regression/threadx_thread_delayed_suspension_test.c')
-rw-r--r--test/smp/regression/threadx_thread_delayed_suspension_test.c33
1 files changed, 21 insertions, 12 deletions
diff --git a/test/smp/regression/threadx_thread_delayed_suspension_test.c b/test/smp/regression/threadx_thread_delayed_suspension_test.c
index 91128f83..fe0a82f8 100644
--- a/test/smp/regression/threadx_thread_delayed_suspension_test.c
+++ b/test/smp/regression/threadx_thread_delayed_suspension_test.c
@@ -1,3 +1,14 @@
+/***************************************************************************/
+/* Copyright (c) 2024 Microsoft Corporation */
+/* Copyright (c) 2026 Eclipse ThreadX contributors */
+/* */
+/* This program and the accompanying materials are made available under */
+/* the terms of the MIT License which is available at */
+/* https://opensource.org/licenses/MIT. */
+/* */
+/* SPDX-License-Identifier: MIT */
+/***************************************************************************/
+
/* This test checks out the delayed suspension clear from tx_thread_resume. */
#include <stdio.h>
@@ -56,7 +67,7 @@ static volatile ULONG destination = 0;
static ULONG start_time;
static ULONG lower_bound;
static ULONG upper_bound;
-static ULONG current_itterations;
+static ULONG current_iterations;
#ifdef DEBUG_1
static ULONG last_loop_count;
#endif
@@ -106,9 +117,9 @@ ULONG i;
if (upper_bound > max_loop_count)
lower_bound = max_loop_count;
- if ((current_itterations < lower_bound) || (current_itterations > upper_bound))
- current_itterations = lower_bound;
-
+ if ((current_iterations < lower_bound) || (current_iterations > upper_bound))
+ current_iterations = lower_bound;
+
#ifdef DEBUG_1
/* Last loop count. */
last_loop_count = loop_count;
@@ -227,7 +238,6 @@ UINT status;
/* Inform user. */
printf("Running Thread Delayed Suspension Clearing Test..................... ");
-
/* Relinquish to the other thread. */
tx_thread_relinquish();
@@ -270,7 +280,6 @@ UINT status;
/* Wait until we see the delayed suspension set flag. */
while(delayed_suspend_set == 0)
{
-
/* Abort the suspension for thread 2. */
tx_thread_wait_abort(&thread_2);
@@ -350,7 +359,7 @@ ULONG i;
lower_bound = lower_bound - 5;
upper_bound = max_loop_count + 5;
- current_itterations = lower_bound;
+ current_iterations = lower_bound;
/* This thread simply suspends over and over... */
while(1)
@@ -366,20 +375,20 @@ ULONG i;
/* Call delay function. */
delay_function();
loop_count++;
- } while (loop_count < current_itterations);
+ } while (loop_count < current_iterations);
/* Suspend this thread. */
tx_semaphore_get(&semaphore_1, TX_WAIT_FOREVER);
- /* Adjust the current itterations. */
- current_itterations++;
- if (current_itterations > upper_bound)
+ /* Adjust the current iterations. */
+ current_iterations++;
+ if (current_iterations > upper_bound)
{
if (lower_bound > min_loop_count)
lower_bound--;
if (upper_bound < max_loop_count)
upper_bound++;
- current_itterations = lower_bound;
+ current_iterations = lower_bound;
}
/* Increment the thread counter. */